==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetRef", "(w:Target,wf:Target)DataRef");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("PropertyPath", "String");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
            a.ad("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", () => new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription());
            a.ac("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription } from "./PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a == null) {
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TargetRef", "(w:Target,wf:Target)DataRef");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("PropertyPath", "String");
        }
        static d(a) {
            PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", () => new PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescription());
            a.ad("PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgs", PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionTargetPropertyUpdatingEventArgsDescriptionMetadata;
})();
